@@ -1,14 +1,12 @@
 from pathlib import Path
 from typing import cast
 
-from recon.corpus import Corpus
-from recon.stats import (
-    calculate_label_distribution_similarity,
-    get_ner_stats,
-)
-from recon.types import NERStats
 from wasabi import Printer
 
+from recon.corpus import Corpus
+from recon.stats import calculate_label_distribution_similarity, get_ner_stats
+from recon.types import Stats
+
 
 def stats(data_dir: Path) -> None:
     """Calculate statistics on a Corpus
@@ -21,7 +19,7 @@ def stats(data_dir: Path) -> None:
 
     def print_stats(corpus: Corpus) -> None:
         for ds, ner_stats in corpus.apply(get_ner_stats).items():
-            ner_stats = cast(NERStats, ner_stats)
+            ner_stats = cast(Stats, ner_stats)
             sorted_labels = sorted(ner_stats.n_annotations_per_type.keys())
 
             msg.text(f"Stats for {ds.capitalize()} data")
