@@ -1,9 +1,9 @@
 from pathlib import Path
-from typing import Any, Callable, List, Tuple, Union
+from typing import Any, Callable, List, Optional, Tuple, Union
 
 import srsly
+
 from recon.dataset import Dataset
-from recon.loaders import read_jsonl
 from recon.store import ExampleStore
 from recon.types import (
     CorpusApplyResult,
@@ -12,7 +12,7 @@ from recon.types import (
     OperationResult,
     OperationState,
 )
-from spacy.util import ensure_path
+from recon.utils import ensure_path
 
 
 class Corpus:
@@ -25,8 +25,8 @@ class Corpus:
         name: str,
         train: Dataset,
         dev: Dataset,
-        test: Dataset = None,
-        example_store: ExampleStore = None,
+        test: Optional[Dataset] = None,
+        example_store: Optional[ExampleStore] = None,
     ):
         """Initialize a Corpus.
 
@@ -34,7 +34,8 @@ class Corpus:
             name (str): Name of the Corpus
             train (Dataset): Dataset containing examples for **train** set
             dev (Dataset): Dataset containing examples for **dev** set
-            test (Dataset, optional): Defaults to None. Dataset containing examples for **test** set
+            test (Optional[Dataset]): Optional Dataset containing examples for **test** set
+            example_store (Optional[ExampleStore]): Optional ExampleStore
         """
         self._name = name
         if example_store is None:
@@ -129,14 +130,22 @@ class Corpus:
     @property
     def example_store(self) -> ExampleStore:
         return self._example_store
-    
-    def print_stats(self) -> str:
-        self.train_ds.print_stats()
-        self.dev_ds.print_stats()
-        if self.test_ds:
-            self.test_ds.print_stats()
 
-    def apply(self, func: Callable[[List[Example], Any, Any], Any], *args: Any, **kwargs: Any) -> CorpusApplyResult:
+    def summary(self) -> str:
+        summaries = [self.train_ds.summary(), self.dev_ds.summary()]
+        if self.test_ds:
+            summaries.append(self.test_ds.summary())
+        return "\n".join(summaries)
+
+    def print_summary(self) -> None:
+        print(self.summary())
+
+    def __str(self) -> str:
+        return self.summary()
+
+    def apply(
+        self, func: Callable[[List[Example], Any], Any], *args: Any, **kwargs: Any
+    ) -> CorpusApplyResult:
         """Apply a function to all datasets
 
         Args:
@@ -154,7 +163,9 @@ class Corpus:
             all=func(self.all, *args, **kwargs),  # type: ignore
         )
 
-    def apply_(self, operation: Callable[[Any], OperationResult], *args: Any, **kwargs: Any) -> None:
+    def apply_(
+        self, operation: Callable[[Any], OperationResult], *args: Any, **kwargs: Any
+    ) -> None:
         """Apply a function to all data inplace.
 
         Args:
@@ -179,12 +190,11 @@ class Corpus:
     @classmethod
     def from_disk(
         cls,
-        data_dir: Path,
+        data_dir: Union[str, Path],
         name: str = "corpus",
         train_name: str = "train",
         dev_name: str = "dev",
         test_name: str = "test",
-        loader_func: Callable = read_jsonl,
     ) -> "Corpus":
         """Load Corpus from disk given a directory with files
         named explicitly train.jsonl, dev.jsonl, and test.jsonl
@@ -194,8 +204,6 @@ class Corpus:
             train_name (str, optional): Name of train data under data_dir. Defaults to train.
             dev_name (str, optional): Name of dev data under data_dir. Defaults to dev.
             test_name (str, optional): Name of test data under data_dir. Defaults to test.
-            loader_func (Callable, optional): Callable that reads a file and returns a List of examples.
-                Defaults to [read_jsonl][recon.loaders.read_jsonl]
         """
         data_dir = ensure_path(data_dir)
 
@@ -209,17 +217,17 @@ class Corpus:
         if example_store_path.exists():
             example_store.from_disk(example_store_path)
 
-        train = Dataset("train", example_store=example_store).from_disk(data_dir)
-        dev = Dataset("dev", example_store=example_store).from_disk(data_dir)
+        train = Dataset(train_name, example_store=example_store).from_disk(data_dir)
+        dev = Dataset(dev_name, example_store=example_store).from_disk(data_dir)
 
         try:
-            test = Dataset("test", example_store=example_store).from_disk(data_dir)
+            test = Dataset(test_name, example_store=example_store).from_disk(data_dir)
             corpus = cls(name, train, dev, test=test)
         except ValueError:
             corpus = cls(name, train, dev)
         return corpus
 
-    def to_disk(self, output_dir: Path, overwrite: bool = False) -> None:
+    def to_disk(self, output_dir: Union[str, Path], overwrite: bool = False) -> None:
         """Save Corpus to Disk
 
         Args:
@@ -228,15 +236,15 @@ class Corpus:
                 and/or overwrite existing data.
         """
         data_dir = ensure_path(output_dir)
-        state_dir = output_dir / ".recon"
+        state_dir = data_dir / ".recon"
         corpus_meta_path = state_dir / "meta.json"
 
-        if not overwrite and output_dir.exists():
+        if not overwrite and data_dir.exists():
             raise ValueError(
                 "Output directory is not empty. Set overwrite=True in Corpus.to_disk to clear the directory before saving."
             )
 
-        output_dir.mkdir(parents=True, exist_ok=True)
+        data_dir.mkdir(parents=True, exist_ok=True)
         if not state_dir.exists():
             state_dir.mkdir(parents=True, exist_ok=True)
 
@@ -253,39 +261,43 @@ class Corpus:
         name: str,
         prodigy_train_datasets: List[str],
         prodigy_dev_datasets: List[str],
-        prodigy_test_datasets: List[str] = None,
+        prodigy_test_datasets: Optional[List[str]] = None,
     ) -> "Corpus":
         """Load a Corpus from 3 separate datasets in Prodigy
 
         Args:
-            prodigy_train_dataset (str, optional): Train dataset name in Prodigy
-            prodigy_dev_dataset (str, optional): Dev dataset name in Prodigy
-            prodigy_test_dataset (str, optional): Test dataset name in Prodigy
+            name: Corpus name
+            prodigy_train_datasets (List[str]): Prodigy datasets to load as Recon train dataset
+            prodigy_dev_datasets (List[str]): Prodigy datasets to load as Recon dev dataset
+            prodigy_test_datasets (Optional[List[str]]): Prodigy datasets to load as Recon test dataset
 
         Returns:
             Corpus: Corpus initialized from prodigy datasets
         """
         train_ds = Dataset("train").from_prodigy(prodigy_train_datasets)
         dev_ds = Dataset("dev").from_prodigy(prodigy_dev_datasets)
-        test_ds = Dataset("test").from_prodigy(prodigy_test_datasets) if prodigy_test_datasets else None
+        test_ds = (
+            Dataset("test").from_prodigy(prodigy_test_datasets) if prodigy_test_datasets else None
+        )
 
         ds = cls(name, train_ds, dev_ds, test_ds)
         return ds
 
     def to_prodigy(
         self,
-        name: str = None,
-        prodigy_train_dataset: str = None,
-        prodigy_dev_dataset: str = None,
-        prodigy_test_dataset: str = None,
+        name: Optional[str] = None,
+        prodigy_train_dataset: Optional[str] = None,
+        prodigy_dev_dataset: Optional[str] = None,
+        prodigy_test_dataset: Optional[str] = None,
         overwrite: bool = True,
     ) -> Tuple[str, str, str]:
         """Save a Corpus to 3 separate Prodigy datasets
 
         Args:
-            prodigy_train_dataset (str, optional): Train dataset name in Prodigy
-            prodigy_dev_dataset (str, optional): Dev dataset name in Prodigy
-            prodigy_test_dataset (str, optional): Test dataset name in Prodigy
+            name (Optional[str]): Name prefix for datasets in Prodigy
+            prodigy_train_dataset (Optional[str]): Train dataset name in Prodigy
+            prodigy_dev_dataset (Optional[str]): Dev dataset name in Prodigy
+            prodigy_test_dataset (Optional[str]): Test dataset name in Prodigy
         """
         name = name if name else self.name
 
