@@ -2,11 +2,12 @@ import tempfile
 from pathlib import Path
 from typing import Iterable, Iterator, List, Set
 
+from spacy.language import Language
+from spacy.training.corpus import Corpus as SpacyCorpus
+from wasabi import Printer
+
 from recon.loaders import to_spacy
 from recon.types import Example, Scores, Span, Token
-from spacy.language import Language
-from spacy.training import Corpus as SpacyCorpus
-from wasabi import Printer
 
 
 class EntityRecognizer:
@@ -44,7 +45,7 @@ class EntityRecognizer:
     def _evaluate(self, examples: List[Example]) -> Scores:
         raise NotImplementedError
 
-    def evaluate(self, examples: List[Example], verbose: bool = True) -> Scores:
+    def evaluate(self, data: List[Example], verbose: bool = True) -> Scores:
         """Evaluate recognizer performance on dataset and print metrics
 
         Args:
@@ -54,7 +55,7 @@ class EntityRecognizer:
         Returns:
             Scorer: spaCy scorer object
         """
-        sc = self._evaluate(examples)
+        sc = self._evaluate(data)
 
         msg = Printer(no_print=not verbose)
         msg.divider("Recognizer Results")
@@ -67,9 +68,11 @@ class EntityRecognizer:
 
         table_data = []
         for label, scores in sorted(sc.ents_per_type.items(), key=lambda tup: tup[0]):
-            table_data.append((label, f"{scores['p']:.3f}", f"{scores['r']:.3f}", f"{scores['f']:.3f}"))
+            table_data.append(
+                (label, f"{scores['p']:.3f}", f"{scores['r']:.3f}", f"{scores['f']:.3f}")
+            )
         header = ("Label", "Precision", "Recall", "F-Score")
-        formatted = msg.table(table_data, header=header, divider=True)
+        msg.table(table_data, header=header, divider=True)
         return sc
 
 
@@ -109,8 +112,6 @@ class SpacyEntityRecognizer(EntityRecognizer):
         Yields:
             Iterator[Example]: Examples constructed from spaCy Model predictions
         """
-        examples: List[Example] = []
-
         for doc in self.nlp.pipe(texts):
             yield Example(
                 text=doc.text,
