@@ -3,35 +3,28 @@ from collections import defaultdict
 from typing import Any, DefaultDict, Dict, List, Optional, Sequence, Union, cast
 
 import numpy as np
-import srsly
-from recon.constants import NOT_LABELED
-from recon.types import EntityCoverage, EntityCoverageStats, Example, NERStats, Outliers
 from scipy.spatial.distance import jensenshannon
 from scipy.stats import entropy as scipy_entropy
 
+from recon.constants import NOT_LABELED
+from recon.types import EntityCoverage, EntityCoverageStats, Example, Outliers, Stats
 
-def get_ner_stats(
-    data: List[Example], serialize: bool = False, return_examples: bool = False
-) -> Union[NERStats, str, None]:
+
+def get_ner_stats(data: List[Example], return_examples: bool = False) -> Stats:
     """Compute statistics for NER data
 
     Args:
         data (Iterator[Example]): Data as a List of examples
-        serialize (bool, optional): Serialize to a JSON string for printing.
         return_examples (bool, optional): Whether to return examples per type
 
     Returns:
-        Union[NERStats, str, None]:
-            List of examples or string if serialize and no_print are both True
+        Stats: Summary stats from list of Examples
     """
     annotations_per_type: DefaultDict[str, Any] = defaultdict(int)
     examples: DefaultDict[str, Any] = defaultdict(list)
     n_examples_no_entities = 0
 
-    length = 0
-
     for e in data:
-        length += 1
         if not e.spans:
             n_examples_no_entities += 1
             examples[NOT_LABELED].append(e)
@@ -40,10 +33,12 @@ def get_ner_stats(
                 annotations_per_type[s.label] += 1
                 examples[s.label].append(e)
 
-    sorted_anns_by_count = {a[0]: a[1] for a in sorted(annotations_per_type.items(), key=lambda x: x[1], reverse=True)}
+    sorted_anns_by_count = {
+        a[0]: a[1] for a in sorted(annotations_per_type.items(), key=lambda x: x[1], reverse=True)
+    }
 
-    stats = NERStats(
-        n_examples=length,
+    stats = Stats(
+        n_examples=len(data),
         n_examples_no_entities=n_examples_no_entities,
         n_annotations=sum(annotations_per_type.values()),
         n_annotations_per_type=sorted_anns_by_count,
@@ -51,18 +46,15 @@ def get_ner_stats(
     if return_examples:
         stats.examples_with_type = examples
 
-    if serialize:
-        return stats.json(indent=4)
-    else:
-        return stats
+    return stats
 
 
-def get_sorted_type_counts(ner_stats: NERStats) -> List[int]:
+def get_sorted_type_counts(ner_stats: Stats) -> List[int]:
     """Get list of counts for each type in n_annotations_per_type property
-    of an NERStats object sorted by type name
+    of an Stats object sorted by type name
 
     Args:
-        ner_stats (NERStats): Dataset stats
+        ner_stats (Stats): Dataset stats
 
     Returns:
         List[int]: List of counts sorted by type name
@@ -94,14 +86,13 @@ def calculate_label_distribution_similarity(x: List[Example], y: List[Example])
     """
 
     def pipeline(data: List[Example]) -> Sequence[float]:
-        stats = cast(NERStats, get_ner_stats(data))
+        stats = cast(Stats, get_ner_stats(data))
         sorted_type_counts = get_sorted_type_counts(stats)
         counts_to_probs = get_probs_from_counts(sorted_type_counts)
         return counts_to_probs
 
     distance = jensenshannon(pipeline(x), pipeline(y))
-
-    return (1 - distance) * 100
+    return float(1 - distance) * 100
 
 
 def get_entity_coverage(
@@ -190,7 +181,7 @@ def calculate_entity_coverage_similarity(x: List[Example], y: List[Example]) ->
     )
 
 
-def get_probs_from_counts(seq: Sequence[int]) -> Sequence[float]:
+def get_probs_from_counts(seq: List[int]) -> Sequence[float]:
     """Convert a sequence of counts to a sequence of probabilties
     by dividing each n by the sum of all n in seq
 
@@ -200,10 +191,10 @@ def get_probs_from_counts(seq: Sequence[int]) -> Sequence[float]:
     Returns:
         Sequence[float]: Sequence of probabilities
     """
-    return np.asarray(seq) / sum(seq)
+    return list(np.asarray(seq) / sum(seq))
 
 
-def entropy(seq: Union[List[int], List[float]], total: int = None) -> float:
+def _entropy(seq: Union[List[int], List[float]], total: Optional[int] = None) -> float:
     """Calculate Shannon Entropy for a sequence of Floats or Integers.
     If Floats, check they are probabilities
     If Integers, divide each n in seq by total and calculate entropy
@@ -222,26 +213,27 @@ def entropy(seq: Union[List[int], List[float]], total: int = None) -> float:
         raise ValueError("Pass a valid non-empty sequence")
 
     if isinstance(seq[0], float):
-        e = scipy_entropy(seq)
+        res = scipy_entropy(seq)
     elif isinstance(seq[0], int):
-        e = scipy_entropy(get_probs_from_counts(seq))
+        seq = cast(List[int], seq)
+        res = scipy_entropy(get_probs_from_counts(seq))
     else:
         raise ValueError("Parameter seq must be a sequence of probabilites or integers.")
-    return e
+    return float(res)
 
 
-def calculate_label_balance_entropy(ner_stats: NERStats) -> float:
-    """Use Entropy to calculate a metric for label balance based on an NERStats object
+def calculate_label_balance_entropy(ner_stats: Stats) -> float:
+    """Use Entropy to calculate a metric for label balance based on a Stats object
 
     Args:
-        ner_stats (NERStats): NERStats for a dataset.
+        ner_stats (Stats): Stats for a dataset.
 
     Returns:
         float: Entropy for annotation counts of each label
     """
     total = ner_stats.n_annotations
-    classes = [count for label, count in ner_stats.n_annotations_per_type.items()]
-    return entropy(classes, total)
+    classes = [count for _, count in ner_stats.n_annotations_per_type.items()]
+    return _entropy(classes, total)
 
 
 def calculate_entity_coverage_entropy(
@@ -257,7 +249,7 @@ def calculate_entity_coverage_entropy(
         float: Entropy for entity coverage counts
     """
     counts = [ecs.count for ecs in entity_coverage]
-    return entropy(counts, sum(counts))  # type: ignore
+    return _entropy(counts, sum(counts))  # type: ignore
 
 
 def detect_outliers(seq: Sequence[Any], use_log: bool = False) -> Outliers:
